"""
Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License").
You may not use this file except in compliance with the License.
A copy of the License is located at

http://aws.amazon.com/apache2.0

or in the "license" file accompanying this file. This file is distributed
on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
express or implied. See the License for the specific language governing
permissions and limitations under the License.

"""
import os
import logging
import json
import base64
import boto3
from datetime import datetime
from decimal import Decimal, ROUND_DOWN

DEBUG_MODE = os.getenv('DEBUG_MODE', 'false')

LOGGER = logging.getLogger(__name__)
os.putenv('LOGGER_NAME', __name__)

if DEBUG_MODE == 'true':
    LOGGER.setLevel(logging.DEBUG)
else:
    LOGGER.setLevel(logging.INFO)

AED_EVENTS_TABLE = str(os.getenv('AED_EVENTS_TABLE',''))
dynamodb = boto3.resource('dynamodb')
table = dynamodb.Table(AED_EVENTS_TABLE)


def lambda_handler(event, context):

    try:
        for record in event['Records']:
            payload_b = base64.b64decode(record["kinesis"]["data"])
            payload = json.loads(payload_b.decode('utf8'))
            LOGGER.info(f'Received event {json.dumps(payload)}')
            #payload = json.loads(json.dumps(payload), parse_float=Decimal)


            timestamp = payload.get('unixtime')
            date = datetime.utcfromtimestamp(int(timestamp)).strftime('%Y-%m-%d')
            data_point = Decimal(payload.get('data')).quantize(Decimal('.000001'), rounding=ROUND_DOWN)

            if timestamp and data_point:
                table.put_item(
                    Item={
                        'date': str(date),
                        'timestamp': str(int(timestamp * 1000000)),
                        'data_point': data_point
                    }
                )
            else:
                LOGGER.error('Event is missing timestamp or data point')

    except:
        LOGGER.exception('Error during the processing of the event')