"""
Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License").
You may not use this file except in compliance with the License.
A copy of the License is located at

http://aws.amazon.com/apache2.0

or in the "license" file accompanying this file. This file is distributed
on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
express or implied. See the License for the specific language governing
permissions and limitations under the License.

"""

from moto import (
    mock_dynamodb2,
)
import boto3
from events_iterator import EventsIterator
from datetime import (
    datetime,
    timedelta,
)

ddb_resource = boto3.resource('dynamodb')
TABLE_NAME = 'stream_data'


@mock_dynamodb2
def test_happy_path():
    prepare_mock_env()

    datetime1 = datetime.strptime('2019-11-07 13:53:42:000001', '%Y-%m-%d %H:%M:%S:%f')
    datetime1_data = 2
    datetime11 = datetime1 + timedelta(microseconds=1)
    datetime11_data = 44
    datetime12 = datetime1 + timedelta(microseconds=2)
    datetime12_data = 44
    datetime2 = datetime1 + timedelta(days=1)
    datetime2_data = 43
    datetime3 = datetime1 + timedelta(days=2)
    datetime3_data = 87
    datetime31 = datetime3 + timedelta(microseconds=1)
    datetime31_data = 39
    datetime32 = datetime3 + timedelta(microseconds=2)
    datetime32_data = 6

    events = [
        (datetime1, datetime1_data),
        (datetime11, datetime11_data),
        (datetime12, datetime12_data),
        (datetime2, datetime2_data),
        (datetime3, datetime3_data),
        (datetime31, datetime31_data),
        (datetime32, datetime32_data)
    ]

    table = ddb_resource.Table(TABLE_NAME)

    put_events(table, events)

    events_iterator = EventsIterator(
        start_date=datetime11.strftime('%Y-%m-%d'),
        end_date=datetime31.strftime('%Y-%m-%d'),
        timestamp=str(int(datetime11.timestamp() * 1000000)),
        ddb_table_name=TABLE_NAME
    )

    for k in events_iterator:
        print(f'#{k}')




def put_events(table, events):
    for date_time, data_point in events:
        date_str = date_time.strftime('%Y-%m-%d')
        timestamp_str = str(int(date_time.timestamp() * 1000000))

        table.put_item(
            Item={
                'date': date_str,
                'timestamp': timestamp_str,
                'data_point': data_point
            }
        )

def prepare_mock_env():
    ddb_resource.create_table(
        TableName=TABLE_NAME,
        KeySchema=[
            {
                'AttributeName': 'date',
                'KeyType': 'HASH'
            },
            {
                'AttributeName': 'timestamp',
                'KeyType': 'RANGE'
            }
        ],
        AttributeDefinitions=[
            {
                'AttributeName': 'dusn',
                'AttributeType': 'S'
            },
            {
                'AttributeName': 'timestamp',
                'AttributeType': 'S'
            }
        ],
        ProvisionedThroughput={
            'ReadCapacityUnits': 5,
            'WriteCapacityUnits': 5
        }
    )
